/*                                                                                                            
 * Copyright (c) Members of the EGEE Collaboration. 2004.
 * See http://eu-egee.org/partners/ for details on the copyright holders.
 * For license conditions see the license file or
 * http://eu-egee.org/license.html
 */

/*                                                                                                            
 * Copyright (c) 2001 EU DataGrid.                                                                             
 * For license conditions see http://www.eu-datagrid.org/license.html                                          
 *
 * Copyright (c) 2001, 2002 by 
 *     Martijn Steenbakkers <martijn@nikhef.nl>,
 *     David Groep <davidg@nikhef.nl>,
 *     Oscar Koeroo <okoeroo@nikhef.nl>,
 *     NIKHEF Amsterdam, the Netherlands
 */

/*!
    \file   lcmaps_types.h
    \brief  Public header file with typedefs for LCMAPS
    \author Martijn Steenbakkers for the EU DataGrid.
    \ingroup APIforLcmapsPlugins

    Last change: support for VOMS' generic attributes  (Placi Flury flury@switch.ch)
*/

#ifndef LCMAPS_TYPES_H
#define LCMAPS_TYPES_H

/******************************************************************************
                             Include header files
******************************************************************************/

/******************************************************************************
                               Type definitions
******************************************************************************/

/*!
    \typedef lcmaps_request_t
    \brief Type of the LCMAPS request expressed in RSL/JDL

    (Internal) just a string.
*/
typedef char *lcmaps_request_t;


typedef struct lcmaps_fqan_unix_s
{
    char * fqan;
    uid_t  uid;
    gid_t  gid;
}
lcmaps_fqan_unix_t;


typedef struct lcmaps_voms_generic_attr_s{  /*!< basically same fields as in the voms_apic.h*/
    const char * name;
    const char * value;
    const char * qualifier;
}
lcmaps_voms_generic_attr_t;


typedef struct lcmaps_voms_s
{
    char *                       user_dn;           /*!< the User DN */
    char *                       user_ca;           /*!< the User CA */
    char *                       voms_issuer_dn;    /*!< the VOMS ACs Issuer (DN) */
    char *                       voms_issuer_ca;    /*!< the VOMS ACs Issuer (CA) */
    char *                       uri;               /*!< the VOMS uri */
    char *                       date1;             /*!< valid begin and end date per VOMS section */
    char *                       date2;             /*!< valid begin and end date per VOMS section */

    char *                       voname;            /*!< The VO name, not in FQAN format, just the name at the server */

    lcmaps_fqan_unix_t *         fqan_unix;         /*!< the list of FQANs mapped with Unix UID and/or Unix GID */
    int                          nfqan;             /*!< the number of FQANs */
    lcmaps_voms_generic_attr_t * attr_list;         /*!< the list of generic voms attributes (name,value) pairs */
    int                          nattr;             /*!< the number of generic voms attributes */
}
lcmaps_voms_t;


typedef struct lcmaps_vomsdata_s
{
    lcmaps_voms_t        *        voms;
    int                           nvoms;
    char                 *        workvo;
    char                 *        extra_data;
}
lcmaps_vomsdata_t;


#endif /* LCMAPS_TYPES_H */

/******************************************************************************
CVS Information:
    $Source: /cvs/glite/org.glite.security.lcmaps/interface/lcmaps_types.h,v $
    $Date: 2007/07/05 14:49:49 $
    $Revision: 1.9 $
    $Author: okoeroo $
******************************************************************************/
